@@ -3,10 +3,10 @@
 
 use fil_actors_runtime::runtime::{ActorCode, Runtime};
 use fil_actors_runtime::{actor_error, wasm_trampoline, ActorError, SYSTEM_ACTOR_ADDR};
-use fvm_ipld_blockstore::Blockstore;
-use fvm_ipld_encoding::tuple::{Deserialize_tuple, Serialize_tuple};
-use fvm_ipld_encoding::RawBytes;
+use fvm_shared::blockstore::Blockstore;
 use fvm_shared::econ::TokenAmount;
+use fvm_shared::encoding::tuple::*;
+use fvm_shared::encoding::RawBytes;
 use fvm_shared::{MethodNum, METHOD_CONSTRUCTOR};
 use num_derive::FromPrimitive;
 use num_traits::FromPrimitive;
@@ -45,9 +45,7 @@ impl Actor {
         RT: Runtime<BS>,
     {
         rt.validate_immediate_caller_is(std::iter::once(&*SYSTEM_ACTOR_ADDR))?;
-        rt.create(&State {
-            entries: params.entries,
-        })?;
+        rt.create(&State { entries: params.entries })?;
         Ok(())
     }
     /// Executes built-in periodic actions, run at every Epoch.
@@ -100,7 +98,7 @@ impl ActorCode for Actor {
                 Self::epoch_tick(rt)?;
                 Ok(RawBytes::default())
             }
-            None => Err(actor_error!(SYS_INVALID_METHOD; "Invalid method")),
+            None => Err(actor_error!(SysErrInvalidMethod; "Invalid method")),
         }
     }
 }
